OC.L10N.register(
    "deck",
    {
    "Please provide a content for your comment." : "Zadajte obsah svojho komentára",
    "Posting the comment failed." : "Nepodarilo sa odoslať komentár",
    "The comment has been deleted" : "Komentár bol odstránený",
    "The associated stack is deleted as well, it will be restored as well." : "Súvisiaci stoh je tiež odstránený a bude tiež obnovený",
    "Restore associated stack" : "Obnoviť súvisiaci stoh",
    "Remove user from card" : "Odobrať používateľa z karty",
    "Hours" : "Hodín",
    "Minutes" : "Minút",
    "Link to a board" : "Odkaz na nástenku",
    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
    "You have created a new board {board}" : "Vytvorili ste nová nástenku {board}",
    "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
    "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
    "{user} has deleted the board {board}" : "Používateľ {user} vymazal nástenku {board}",
    "You have restored the board {board}" : "Obnovili ste nástenku {board}",
    "{user} has restored the board {board}" : "Používateľ {user} obnovil nástenku {board}",
    "You have shared the board {board} with {acl}" : "Sprístupnili ste nástenku {board} s {acl}",
    "{user} has shared the board {board} with {sharee}" : "Používateľ {user} sprístupnil nástenku {board} pre {sharee}",
    "You have removed {acl} from the board {board}" : "Odobrali ste {acl} z nástenky {board}",
    "{user} has removed {acl} from the board {board}" : "Používateľ {user} odobral {acl} z nástenky {board}",
    "You have renamed the board {before} to {board}" : "Premenovali ste nástenku {before} na {board}",
    "{user} has renamed the board {before} to {board}" : "Používateľ {user} premenoval nástenku {before} na {board}",
    "You have archived the board {board}" : "Archivovali ste nástenku {board}",
    "{user} has archived the board {before}" : "Používateľ {user} archivoval nástenku {board}",
    "You have unarchived the board {board}" : "Zrušili ste archiváciu nástenky {board}",
    "{user} has unarchived the board {before}" : "Používateľ {user} zrušil archiváciu nástenky {before}",
    "You have created a new stack {stack} on board {board}" : "Vytvorili ste nový stoh {stack} na nástenke {board}",
    "{user} has created a new stack {stack} on board {board}" : "Používateľ {user} vytvoril nový stoh {stack} na nástenke {board}",
    "You have renamed stack {before} to {stack} on board {board}" : "Premenovali ste stoh {before} na {stack} na nástenke {board}",
    "{user} has renamed stack {before} to {stack} on board {board}" : "Používateľ {user} premenoval stoh {before} na {stack} na nástenke {board}",
    "You have deleted stack {stack} on board {board}" : "Vymazali ste stoh {stack} z nástenky {board}",
    "{user} has deleted stack {stack} on board {board}" : "Používateľ {user} vymazal stoh {stack} z nástenky {board}",
    "You have created card {card} in stack {stack} on board {board}" : "Vytvorili ste kartu {card} v stohu {stack} na nástenke {board}",
    "{user} has created card {card} in stack {stack} on board {board}" : "Používateľ {user} vytvoril kartu {card} v stohu {stack} na nástenke {board}",
    "You have deleted card {card} in stack {stack} on board {board}" : "Vymazali ste kartu {card} v stohu {stack} z nástenky {board}",
    "{user} has deleted card {card} in stack {stack} on board {board}" : "Používateľ {user} vymazal kartu {card} v stohu {stack} z nástenky {board}",
    "You have renamed the card {before} to {card}" : "Premenovali ste kartu {before} na {card}",
    "{user} has renamed the card {before} to {card}" : "Používateľ {user} premenoval kartu {before} na {card}",
    "You have added a description to card {card} in stack {stack} on board {board}" : "Pridali ste popis ku karte {card} v stohu {stack} na nástenke {board}",
    "{user} has added a description to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal popis ku karte {card} v stohu {stack} na nástenke {board}",
    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali ste popis v karte {card} v stohu {stack} na nástenke {board}",
    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "Používateľ {user} aktualizoval popis karty {card} v stohu {stack} na nástenke {board}",
    "You have archived card {card} in stack {stack} on board {board}" : "Archivovali ste kartu {card} v stohu {stack} na nástenke {board}",
    "{user} has archived card {card} in stack {stack} on board {board}" : "Používateľ {user} archivoval kartu {card} v stohu {stack} na nástenke {board}",
    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v stohu {stack} na nástenke {board}",
    "{user} has unarchived card {card} in stack {stack} on board {board}" : "Používateľ {user} zrušil archiváciu karty {card} v stohu {stack} na nástenke {board}",
    "You have removed the due date of card {card}" : "Odobrali ste termín dokončenia z karty {card}",
    "{user} has removed the due date of card {card}" : "Používateľ {user} odobral termín dokončenia z karty {card}",
    "You have set the due date of card {card} to {after}" : "Nastavili ste termín dokončenia pre kartu {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "Používateľ {user} nastavil termín dokončenia karty {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Zmenili ste termín dokončenia karty {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "Používateľ {user} aktualizoval termín dokončenia karty {card} na {after}",
    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v stohu {stack} na nástenke {board}",
    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal štítok {label} ku karte {card} v stohu {stack} na nástenke {board}",
    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odobrali ste štítok {label} z karty {card} v stohu {stack} na nástenke {board}",
    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "Používateľ {user} odobral štítok {label} z karty {card} v stohu {stack} na nástenke {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Priradili ste používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "Používateľ {user} priradil používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Vyradili ste priradenie používateľa {assigneduser} z karty {card} na nástenke {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Používateľ {user} vyradil používateľa {assigneduser} z karty {card} na nástenke {board}",
    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo stohu {stackBefore} do stohu {stack}",
    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "Používateľ {user} presunul kartu {card} zo stohu {stackBefore} do stohu {stack}",
    "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
    "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
    "{user} has updated the attachment {attachment} to card {card}" : "Používateľ {user} aktualizoval prílohu {attachment} ku karte {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Vymazali ste prílohu {attachment} na karte {card}",
    "{user} has deleted the attachment {attachment} to card {card}" : "Používateľ {user} vymazal prílohu {attachment} z karty {card}",
    "You have restored the attachment {attachment} to card {card}" : "Obnovili ste prílohu {attachment} na karte {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "Používateľ {user} obnovil prílohu {attachment} na karte {card}",
    "You have commented on card {card}" : "Komentovali ste kartu {card}",
    "{user} has commented on card {card}" : "{user} komentoval(a) kartu {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "V apke Nástenka sa zmenil <strong>Popis karty</strong>",
    "Deck" : "Nástenka",
    "Changes in the <strong>Deck app</strong>" : "Zmeny v apke <strong>Nástenka</strong>",
    "Personal" : "Osobné",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "Používateľ {user} vám priradil kartu „%s“ na „%s“.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na nástenke \"%s\" dosiahla termín dokončenia.",
    "%s has mentioned you in a comment on \"%s\"." : "Používateľ %s vás zmienil v komentári ku „%s“.",
    "{user} has mentioned you in a comment on \"%s\"." : "Používateľ {user} vás zmienil v komentári v „%s“.",
    "The board \"%s\" has been shared with you by %s." : "Používateľ %s vám sprístupnil nástenku \"%s\".",
    "{user} has shared the board %s with you." : "Používateľ {user} vám sprístupnil nástenku %s.",
    "No data was provided to create an attachment." : "Neboli poskytnuté dáta pre vytvorenie prílohy.",
    "Finished" : "Ukončené",
    "To review" : "Na posúdenie",
    "Action needed" : "Potrebná akcia",
    "Later" : "Neskôr",
    "To do" : "Urobiť",
    "Doing" : "Prebieha",
    "Done" : "Hotové",
    "Example Task 3" : "Príklad úlohy 3",
    "Example Task 2" : "Príklad úlohy 2",
    "Example Task 1" : "Príklad úlohy 1",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor bol nahraný iba čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
    "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
    "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
    "A kanban style project and personal management tool for Nextcloud" : "Nástroj pre projektové a osobné riadenie v štýle Kanban.",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
    "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
    "Select board" : "Vybrať nástenku",
    "Add a new stack" : "Pridať nový stoh",
    "Submit" : "Odoslať",
    "Show archived cards" : "Zobraziť archivované karty",
    "Hide archived cards" : "Skryť archivované karty",
    "Toggle compact mode" : "Vyp/zap. kompaktný režim",
    "Show board details" : "Zobraziť podrobnosti o nástenke",
    "All Boards" : "Všetky nástenky",
    "Archived boards" : "Archivované nástenky",
    "Share board" : "Zdieľať nástenku",
    "Archived cards" : "Archivované karty",
    "Actions" : "Akcie",
    "Drop your files here to upload it to the card" : "Tu vložte svoje súbory ak ich chcete pripojiť ku karte.",
    "Assign card to me" : "Priradiť kartu mne",
    "Unassign card from me" : "Zrušiť priradenie karty mne",
    "Archive card" : "Archivovať kartu",
    "Unarchive card" : "Zrušiť archiváciu karty",
    "Delete card" : "Zmazať kartu",
    "Enter a card title" : "Zmeniť názov karty",
    "Add card" : "Pridať kartu",
    "Close" : "Zavrieť",
    "Sharing" : "Sprístupnenie",
    "Tags" : "Štítky",
    "Deleted items" : "Zmazané položky",
    "Timeline" : "Časová os",
    "Select users or groups to share with" : "Vyberte používateľov albo skupiny pre sprístupnenie",
    "Group" : "Skupina",
    "Circle" : "Kruh",
    "No matching user or group found." : "Neboli nájdení vyhovujúci používatelia alebo skupiny.",
    "Loading" : "Načítavanie",
    "Edit" : "Upraviť",
    "Share" : "Sprístupniť",
    "Manage" : "Spravovať",
    "Discard share" : "Zrušiť sprístupnenie",
    "Sharing has been disabled for your account." : "Sprístupňovanie bolo pre vaše konto zakázané.",
    "Update tag" : "Aktualizovať štítok",
    "Edit tag" : "Upraviť štítok",
    "Delete tag" : "Zmazať štítok",
    "Create" : "Vytvoriť",
    "Create a new tag" : "Vytvoriť nový štítok",
    "Deleted stacks" : "Odstránené stohy",
    "Deleted cards" : "Odstránené karty",
    "Status" : "Stav",
    "No archived boards to display" : "Žiadne archivované nástenky",
    "No shared boards to display" : "Žiadne sprístupnené nástenky",
    "Title" : "Názov",
    "Members" : "Členovia",
    "More actions" : "Viac akcií",
    "Edit board" : "Upraviť nástenku",
    "Archive board" : "Archivovať nástenku",
    "Unarchive board" : "Vybrať nástenku z archívu",
    "Delete board" : "Zmazať nástenku",
    "Update board" : "Aktualizovať nástenku",
    "Reset board" : "Resetovať nástenku",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Vrátiť späť vymazanie nástenky - v opačnom prípade bude nástenka vymazaná počas ďalšieho behu úlohy cronjob.",
    "Create new board" : "Vytvoriť novú nástenku",
    "New board title" : "Názov novej nástenky",
    "Create board" : "Vytvoriť nástenku",
    "Select an attachment" : "Vybrať prílohu",
    "Cancel upload" : "Zrušiť nahrávanie",
    "by" : "-",
    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Vrátiť späť zmazanie súboru - v opačnom prípade bude súbor vymazaný počas ďalšieho behu úlohy cronjob.",
    "Undo file deletion" : "Vrátiť späť odstránenie súboru",
    "Insert the file into the description" : "Vložte súbor do popisu",
    "Delete attachment" : "Zmazať prílohu",
    "Modified:" : "Upravené:",
    "Created:" : "Vytvorené:",
    "Choose a tag" : "Vybrať štítok",
    "Add a tag" : "Pridať štítok",
    "Select tags" : "Zvoliť štítky",
    "Assign users" : "Priradiť používateľov",
    "Choose a user to assign" : "Vyberte používateľa, ktorého chcete priradiť",
    "Assign this card to a user" : "Priradiť túto kartu používateľovi",
    "Due date" : "Termín dokončenia",
    "Click to set" : "Kliknite pre nastavenie",
    "Remove due date" : "Odstrániť termín dokončenia",
    "Description" : "Popis",
    "Attachments" : "Prílohy",
    "Saved" : "Uložené",
    "Unsaved changes" : "Neuložené zmeny",
    "Insert attachment" : "Vložiť prílohu",
    "Formatting help" : "Pomoc pri formátovaní",
    "Upload attachment" : "Nahrať prílohu",
    "Add a card description…" : "Pridať popis karty...",
    "Shared boards" : "Sprístupnené nástenky",
    "Move board to archive" : "Presunúť nástenku do archívu",
    "Create a new board" : "Vytvoriť novú nástenku",
    "Settings" : "Nastavenia",
    "Limit deck to groups" : "Obmedziť nástenku pre skupiny",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
